@@ -1,5 +1,5 @@
 /*
- ** Copyright (©) 2003-2012 Teus Benschop.
+ ** Copyright (©) 2003-2013 Teus Benschop.
  **  
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -46,9 +46,9 @@ AssistantBase("Remote repository setup", "menu-preferences/dialog-remote-reposit
   persistent_clone_directory = git_testing_directory ("clone");
   write_access_granted = false;
   ignore_entry_repository_changed = false;
-    
+
   gtk_assistant_set_forward_page_func (GTK_ASSISTANT (assistant), GtkAssistantPageFunc (assistant_forward_function), gpointer(this), NULL);
-  
+
   g_signal_connect (G_OBJECT (assistant), "apply", G_CALLBACK (on_assistant_apply_signal), gpointer(this));
   g_signal_connect (G_OBJECT (assistant), "prepare", G_CALLBACK (on_assistant_prepare_signal), gpointer(this));
 
@@ -89,7 +89,7 @@ AssistantBase("Remote repository setup", "menu-preferences/dialog-remote-reposit
   // System for trying out git.
   git_tried_and_okay = false;
   
-  label_try_git = gtk_label_new ("The content tracker has been tested and works fine");
+  label_try_git = gtk_label_new ("The local content tracker has been tested and works fine");
   gtk_widget_show (label_try_git);
   page_number_try_git = gtk_assistant_append_page (GTK_ASSISTANT (assistant), label_try_git);
 
@@ -315,22 +315,25 @@ void RemoteRepositoryAssistant::on_assistant_prepare (GtkWidget *page)
   ProjectConfiguration *projectconfig = settings->projectconfig(bible);
   
   if (page == checkbutton_use_repository) {
-    // Set all values in the GUI, according to the project configuration if it is a Bible, or the general configuration for project notes.
+    // Set all values in the GUI, according to the project configuration if it is a Bible, 
+    // or the general configuration for project notes.
 
     // Whether to use the remote repository.
     bool use_remote_repository = false;
-    if (bible_notes_selector_bible ())
+    if (bible_notes_selector_bible ()) {
       use_remote_repository = projectconfig->git_use_remote_repository_get();
-    else
+    } else {
       use_remote_repository = settings->genconfig.consultation_notes_git_use_remote_repository_get();
+    }
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbutton_use_repository), use_remote_repository);
 
     // Set the repository location.
     ustring repository_url;
-    if (bible_notes_selector_bible ())
+    if (bible_notes_selector_bible ()) {
       repository_url = projectconfig->git_remote_repository_url_get();
-    else
+    } else {
       repository_url = settings->genconfig.consultation_notes_git_remote_repository_url_get();
+    }
     ignore_entry_repository_changed = true;
     gtk_entry_set_text (GTK_ENTRY (entry_repository), repository_url.c_str());
     ignore_entry_repository_changed = false;
@@ -436,7 +439,7 @@ void RemoteRepositoryAssistant::on_assistant_apply ()
     unix_rmdir(destination_data_directory);
     unix_mv(persistent_clone_directory, destination_data_directory);
     // Switch rename detection off. 
-    // This is necessary for the consultation notes, since git has been seen to detect spurious renames.
+    // This is necessary for the consultation notes, since git has been seen to cause spurious renames.
     GwSpawn spawn ("git");
     spawn.workingdirectory (destination_data_directory);
     spawn.arg ("config");
@@ -888,8 +891,7 @@ ustring RemoteRepositoryAssistant::repository_url_get()
 {
   ustring url;
   url = gtk_entry_get_text (GTK_ENTRY (entry_repository));
-  url = trim(url);
-  replace_text(url, "http", "");
+  url = trim (url);
   return url;
 }
 
