@@ -1,5 +1,5 @@
 /*
- ** Copyright (©) 2003-2012 Teus Benschop.
+ ** Copyright (©) 2003-2013 Teus Benschop.
  **  
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -42,8 +42,9 @@ VCS *vcs;
 
 int main(int argc, char *argv[])
 {
-  // Initialize g types.
-  g_type_init();
+  // g_type_init has been deprecated since version 2.36.
+  // The type system is now initialised automatically.
+  // g_type_init();
 
   // Settings object. 
   Settings mysettings(true);
