@@ -1,5 +1,5 @@
 /*
-** Copyright (©) 2003-2012 Teus Benschop.
+** Copyright (©) 2003-2013 Teus Benschop.
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -81,8 +81,8 @@ vector < ustring > config_xml_vector_string_get(const ustring & file, const ustr
   // resource creation, but it appeared that it didn't solve the problem.
   // Yet the mutex was left, because the configurations are accessed in 
   // a thread, so it is always good to have a mutex in place.
-  static GStaticMutex config_xml_vector_string_get_mutex = G_STATIC_MUTEX_INIT;
-  g_static_mutex_lock(&config_xml_vector_string_get_mutex);
+  static GMutex config_xml_vector_string_get_mutex = G_STATIC_MUTEX_INIT;
+  g_mutex_lock (&config_xml_vector_string_get_mutex);
 
   vector < ustring > value;
   if (g_file_test(file.c_str(), G_FILE_TEST_IS_REGULAR)) {
@@ -138,7 +138,7 @@ vector < ustring > config_xml_vector_string_get(const ustring & file, const ustr
       g_free(contents);
   }
 
-  g_static_mutex_unlock(&config_xml_vector_string_get_mutex);
+  g_mutex_unlock (&config_xml_vector_string_get_mutex);
 
   return value;
 }
