@@ -1,5 +1,5 @@
 /*
-** Copyright (©) 2003-2012 Teus Benschop.
+** Copyright (©) 2003-2013 Teus Benschop.
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -50,7 +50,7 @@
 #define NEW_PROJECT "New Project"
 
 
-ProjectDialog::ProjectDialog(bool newproject)
+ProjectDialog::ProjectDialog (bool newproject)
 {
   // Settings.
   extern Settings *settings;
@@ -58,11 +58,12 @@ ProjectDialog::ProjectDialog(bool newproject)
   // Save variables.
   if (newproject) {
     // Make "New Project".
-    project_create_restore(NEW_PROJECT, "");
+    project_create_restore (NEW_PROJECT, "");
     currentprojectname = NEW_PROJECT;
   } else {
-    currentprojectname = settings->genconfig.project_get();
+    currentprojectname = settings->genconfig.project_get ();
   }
+  focusbook = 0;
 
   // Get project information.
   ProjectConfiguration *projectconfig = settings->projectconfig(settings->genconfig.project_get());
@@ -103,13 +104,13 @@ ProjectDialog::ProjectDialog(bool newproject)
   gtk_widget_show(messagelabel);
   gtk_box_pack_start(GTK_BOX(vbox1), messagelabel, FALSE, FALSE, 0);
 
-  checkbutton_editable = gtk_check_button_new_with_mnemonic("Editable");
+  checkbutton_editable = gtk_check_button_new_with_mnemonic ("Editable");
   gtk_widget_show(checkbutton_editable);
   gtk_box_pack_start(GTK_BOX(vbox1), checkbutton_editable, FALSE, FALSE, 0);
 
   shortcuts.button(checkbutton_editable);
 
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbutton_editable), projectconfig->editable_get());
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbutton_editable), projectconfig->editable_get() || newproject);
 
   table1 = gtk_table_new(3, 3, FALSE);
   gtk_widget_show(table1);
@@ -394,17 +395,17 @@ void ProjectDialog::set_gui()
 }
 
 
-void ProjectDialog::on_ok()
+void ProjectDialog::on_ok ()
 {
   // Deal with possible new projectname.
   if (currentprojectname != newprojectname) {
     // Move project.
-    project_move(currentprojectname, newprojectname);
+    project_move (currentprojectname, newprojectname);
   }
   // Save settings.
   extern Settings *settings;
   settings->genconfig.project_set(newprojectname);
-  ProjectConfiguration *projectconfig = settings->projectconfig(settings->genconfig.project_get());
+  ProjectConfiguration *projectconfig = settings->projectconfig (settings->genconfig.project_get ());
   projectconfig->versification_set(combobox_get_active_string(combobox_versification));
   projectconfig->language_set(combobox_get_active_string(combobox_language));
   projectconfig->editable_set(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbutton_editable)));
@@ -486,6 +487,14 @@ void ProjectDialog::on_ok()
     }
 
   }
+  
+  // Set the book to focus in the editor.
+  if (focusbook == 0) {
+    vector <unsigned int> books = project_get_books (newprojectname);
+    if (books.size () > 0) {
+      focusbook = books [0];
+    }
+  }
 
 }
 
@@ -505,17 +514,17 @@ void ProjectDialog::on_book_add()
  * If the user adds book(s), templates of the book are placed in the project.
  * The templates contain markers for chapters, verses, and the basics.
  */
-  vector < unsigned int >selectables;
-  set < unsigned int >selection;
-  vector < unsigned int >scripture_books = project_get_books(currentprojectname);
-  set < unsigned int >currentbooks;
+  vector <unsigned int> selectables;
+  set <unsigned int> selection;
+  vector <unsigned int> scripture_books = project_get_books (currentprojectname);
+  set <unsigned int> currentbooks;
   for (unsigned int i = 0; i < scripture_books.size(); i++)
-    currentbooks.insert(scripture_books[i]);
+    currentbooks.insert (scripture_books[i]);
   {
-    vector < unsigned int >ids = books_type_to_ids(btUnknown);
+    vector <unsigned int> ids = books_type_to_ids (btUnknown);
     for (unsigned int i = 0; i < ids.size(); i++) {
       if (currentbooks.find(ids[i]) == currentbooks.end())
-        selectables.push_back(ids[i]);
+        selectables.push_back (ids[i]);
     }
   }
   books_standard_order(selectables);
@@ -526,15 +535,15 @@ void ProjectDialog::on_book_add()
   int result = dialog.run();
   if (result == GTK_RESPONSE_OK) {
     selection = dialog.selectionset;
-    vector < unsigned int >ids = books_type_to_ids(btUnknown);
-    ProgressWindow progresswindow("Adding books", false);
-    progresswindow.set_iterate(0, 1, ids.size());
+    vector <unsigned int> ids = books_type_to_ids(btUnknown);
+    ProgressWindow progresswindow ("Adding books", false);
+    progresswindow.set_iterate (0, 1, selection.size());
     for (unsigned int i = 0; i < ids.size(); i++) {
-      progresswindow.iterate();
       if (!(selection.find(ids[i]) == selection.end())) {
-        vector < ustring > booktemplate;
+        progresswindow.iterate();
+        vector <ustring> booktemplate;
         // If the book is found in the templates, take that, else create it.
-        ustring englishbook = books_id_to_english(ids[i]);
+        ustring englishbook = books_id_to_english (ids[i]);
         ustring templatefile = englishbook.casefold() + ".usfm";
         replace_text(templatefile, " ", "_");
         templatefile = gw_build_filename(directories_get_package_data(), templatefile);
@@ -557,6 +566,10 @@ void ProjectDialog::on_book_add()
         }
         CategorizeChapterVerse ccv(booktemplate);
         project_store_book(currentprojectname, ids[i], ccv);
+        // The book to be focused in the Bible text editor.
+        if (focusbook == 0) {
+          focusbook = ids[i];
+        }
       }
     }
   }
@@ -607,8 +620,9 @@ void ProjectDialog::on_book_delete()
 
   }
   // Update GUI.
-
   set_gui();
+  // No book yet to focus in the Bible text editor.
+  focusbook = 0;
 }
 
 
