@@ -1,5 +1,5 @@
 /*
-** Copyright (©) 2003-2012 Teus Benschop.
+** Copyright (©) 2003-2013 Teus Benschop.
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@
 Httpd::Httpd(bool dummy)
 // This is a basic webserver tailored to Bibledit's specific needs.
 {
-  g_thread_create(GThreadFunc(thread_start), gpointer(this), false, NULL);
+  g_thread_new ("httpd", GThreadFunc (thread_start), gpointer(this));
 }
 
 Httpd::~Httpd()
