@@ -1,5 +1,5 @@
 /*
-** Copyright (©) 2003-2012 Teus Benschop.
+** Copyright (©) 2003-2013 Teus Benschop.
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -136,7 +136,7 @@ void kjv_action_page (HtmlWriter2& htmlwriter)
 
   // Write OK.
   htmlwriter.paragraph_open ();
-  htmlwriter.hyperlink_add ("", "Ok");
+  htmlwriter.hyperlink_add ("ok", "Ok");
   htmlwriter.paragraph_close ();
 }
 
