@@ -1,5 +1,5 @@
 /*
- ** Copyright (©) 2003-2012 Teus Benschop.
+ ** Copyright (©) 2003-2013 Teus Benschop.
  **  
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -187,17 +187,6 @@ protected:
   GtkWidget *view_outline;
   GtkWidget *insert1;
   GtkWidget *insert1_menu;
-  GtkWidget *standard_text_1;
-  GtkWidget *image1963;
-  GtkWidget *standard_text_2;
-  GtkWidget *image1964;
-  GtkWidget *standard_text_3;
-  GtkWidget *image1965;
-  GtkWidget *standard_text_4;
-  GtkWidget *image1966;
-  GtkWidget *separator9;
-  GtkWidget *current_reference1;
-  GtkWidget *image3797;
   GtkWidget *insert_special_character;
   GtkWidget *insert_footnote;
   GtkWidget *insert_xref;
@@ -239,8 +228,6 @@ protected:
   GtkWidget *check_punctuation_menu;
   GtkWidget *check_matching_pairs;
   GtkWidget *image7367;
-  GtkWidget *check_sentence_structure;
-  GtkWidget *image28475;
   GtkWidget *check_references;
   GtkWidget *image21826;
   GtkWidget *check_references_menu;
@@ -465,12 +452,6 @@ protected:
   static void on_find_in_notes1_activate(GtkMenuItem *menuitem, gpointer user_data);
   void find_in_notes();
   void on_import_notes();
-  static void on_standard_text_1_activate(GtkMenuItem *menuitem, gpointer user_data);
-  static void on_standard_text_2_activate(GtkMenuItem *menuitem, gpointer user_data);
-  static void on_standard_text_3_activate(GtkMenuItem *menuitem, gpointer user_data);
-  static void on_standard_text_4_activate(GtkMenuItem *menuitem, gpointer user_data);
-  void on_insert_standard_text(GtkMenuItem *menuitem);
-  static void on_current_reference1_activate(GtkMenuItem *menuitem, gpointer user_data);
   static void on_menuitem_view_activate(GtkMenuItem *menuitem, gpointer user_data);
   void on_menuitem_view();
   static void on_get_references_from_note_activate(GtkMenuItem *menuitem, gpointer user_data);
@@ -522,8 +503,6 @@ protected:
   void on_synoptic_parallel_passages_from_the_nt();
   static void on_parallels_from_the_ot_activate(GtkMenuItem *menuitem, gpointer user_data);
   void on_parallels_from_the_ot();
-  static void on_check_sentence_structure_activate(GtkMenuItem *menuitem, gpointer user_data);
-  void on_check_sentence_structure();
   static void on_check_spelling_error_next_activate (GtkMenuItem *menuitem, gpointer user_data);
   static void on_check_spelling_error_previous_activate (GtkMenuItem *menuitem, gpointer user_data);
   void on_check_spelling_error(bool next, bool extremity);
@@ -701,11 +680,6 @@ protected:
   static void accelerator_cut_callback(gpointer user_data);
   static void accelerator_copy_callback(gpointer user_data);
   static void accelerator_paste_callback(gpointer user_data);
-  static void accelerator_standard_text_1_callback(gpointer user_data);
-  static void accelerator_standard_text_2_callback(gpointer user_data);
-  static void accelerator_standard_text_3_callback(gpointer user_data);
-  static void accelerator_standard_text_4_callback(gpointer user_data);
-  void accelerator_standard_text_n(unsigned int selector);
   static void accelerator_new_project_note_callback(gpointer user_data);
   static void accelerator_next_verse_callback(gpointer user_data);
   static void accelerator_previous_verse_callback(gpointer user_data);
@@ -736,10 +710,6 @@ protected:
   static void accelerator_main_help_callback(gpointer user_data);
   static void accelerator_view_usfm_code(gpointer user_data);
   void accelerator_view_usfm_code_toggle();
-  static void accelerator_left_square_bracket(gpointer user_data);
-  void left_square_bracket ();
-  static void accelerator_right_square_bracket(gpointer user_data);  
-  void right_square_bracket ();
   
   // Shutdown.
   bool shutting_down;
