@@ -1,5 +1,5 @@
 /*
- ** Copyright (©) 2003-2012 Teus Benschop.
+ ** Copyright (©) 2003-2013 Teus Benschop.
  **  
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -76,7 +76,7 @@ void WindowsOutpost::Start()
 // This effectually starts the whole system.
 {
   thread_run = true;
-  g_thread_create(GThreadFunc(thread_start), gpointer(this), false, NULL);
+  g_thread_new ("windowsoutpost", GThreadFunc(thread_start), gpointer(this));
 }
 
 
